Class Reference
===============

This is the main python binding for chardetng, a rust character encoding
detector for legacy Web content.

The class here is a wrapper around the rust struct ``EncodingDetector``.
The documentation for the rust structure is available on
`docs.rs <https://docs.rs/chardetng/>`__.

For more information about the overall function of the library, read
Henri Sivonen’s `excellent write-up <https://hsivonen.fi/chardetng/>`__.

chardetng_py.detector
---------------------

.. automodule:: chardetng_py.detector
   :members:
   :undoc-members:
